@@ -1,6 +1,6 @@
 # django-openid-auth -  OpenID integration for django.contrib.auth
 #
-# Copyright (C) 2009-2013 Canonical Ltd.
+# Copyright (C) 2009-2020 Canonical Ltd.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -26,8 +26,10 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
+from __future__ import unicode_literals
+
+import base64
 import time
-import unittest
 
 from django.test import TestCase
 from openid.association import Association as OIDAssociation
@@ -49,12 +51,13 @@ class OpenIDStoreTests(TestCase):
 
         dbassoc = Association.objects.get(
             server_url='server-url', handle='handle')
-        self.assertEquals(dbassoc.server_url, 'server-url')
-        self.assertEquals(dbassoc.handle, 'handle')
-        self.assertEquals(dbassoc.secret, 'secret'.encode('base-64'))
-        self.assertEquals(dbassoc.issued, 42)
-        self.assertEquals(dbassoc.lifetime, 600)
-        self.assertEquals(dbassoc.assoc_type, 'HMAC-SHA1')
+        self.assertEqual(dbassoc.server_url, 'server-url')
+        self.assertEqual(dbassoc.handle, 'handle')
+        self.assertEqual(
+            dbassoc.secret, base64.b64encode(b'secret').decode('utf-8'))
+        self.assertEqual(dbassoc.issued, 42)
+        self.assertEqual(dbassoc.lifetime, 600)
+        self.assertEqual(dbassoc.assoc_type, 'HMAC-SHA1')
 
     def test_storeAssociation_update_existing(self):
         assoc = OIDAssociation('handle', 'secret', 42, 600, 'HMAC-SHA1')
@@ -65,7 +68,8 @@ class OpenIDStoreTests(TestCase):
         self.store.storeAssociation('server-url', assoc)
         dbassoc = Association.objects.get(
             server_url='server-url', handle='handle')
-        self.assertEqual(dbassoc.secret, 'secret2'.encode('base-64'))
+        self.assertEqual(
+            dbassoc.secret, base64.b64encode(b'secret2').decode('utf-8'))
         self.assertEqual(dbassoc.issued, 420)
         self.assertEqual(dbassoc.lifetime, 900)
         self.assertEqual(dbassoc.assoc_type, 'HMAC-SHA256')
@@ -78,15 +82,15 @@ class OpenIDStoreTests(TestCase):
         assoc = self.store.getAssociation('server-url', 'handle')
         self.assertTrue(isinstance(assoc, OIDAssociation))
 
-        self.assertEquals(assoc.handle, 'handle')
-        self.assertEquals(assoc.secret, 'secret')
-        self.assertEquals(assoc.issued, timestamp)
-        self.assertEquals(assoc.lifetime, 600)
-        self.assertEquals(assoc.assoc_type, 'HMAC-SHA1')
+        self.assertEqual(assoc.handle, 'handle')
+        self.assertEqual(assoc.secret, b'secret')
+        self.assertEqual(assoc.issued, timestamp)
+        self.assertEqual(assoc.lifetime, 600)
+        self.assertEqual(assoc.assoc_type, 'HMAC-SHA1')
 
     def test_getAssociation_unknown(self):
         assoc = self.store.getAssociation('server-url', 'unknown')
-        self.assertEquals(assoc, None)
+        self.assertEqual(assoc, None)
 
     def test_getAssociation_expired(self):
         lifetime = 600
@@ -97,7 +101,7 @@ class OpenIDStoreTests(TestCase):
 
         # The association is not returned, and is removed from the database.
         assoc = self.store.getAssociation('server-url', 'handle')
-        self.assertEquals(assoc, None)
+        self.assertEqual(assoc, None)
         self.assertRaises(Association.DoesNotExist, Association.objects.get,
                           server_url='server-url', handle='handle')
 
@@ -113,22 +117,22 @@ class OpenIDStoreTests(TestCase):
 
         # The newest handle is returned.
         assoc = self.store.getAssociation('server-url', None)
-        self.assertNotEquals(assoc, None)
-        self.assertEquals(assoc.handle, 'handle1')
-        self.assertEquals(assoc.issued, timestamp + 1)
+        self.assertNotEqual(assoc, None)
+        self.assertEqual(assoc.handle, 'handle1')
+        self.assertEqual(assoc.issued, timestamp + 1)
 
     def test_removeAssociation(self):
         timestamp = int(time.time())
         self.store.storeAssociation(
             'server-url', OIDAssociation('handle', 'secret', timestamp, 600,
                                          'HMAC-SHA1'))
-        self.assertEquals(
+        self.assertEqual(
             self.store.removeAssociation('server-url', 'handle'), True)
-        self.assertEquals(
+        self.assertEqual(
             self.store.getAssociation('server-url', 'handle'), None)
 
     def test_removeAssociation_unknown(self):
-        self.assertEquals(
+        self.assertEqual(
             self.store.removeAssociation('server-url', 'unknown'), False)
 
     def test_useNonce(self):
@@ -182,12 +186,8 @@ class OpenIDStoreTests(TestCase):
             'server-url', OIDAssociation('handle2', 'secret', timestamp,
                                          200, 'HMAC-SHA1'))
 
-        self.assertEquals(self.store.cleanupAssociations(), 1)
+        self.assertEqual(self.store.cleanupAssociations(), 1)
 
         # The second (non-expired) association is left behind.
         self.assertNotEqual(self.store.getAssociation('server-url', 'handle2'),
                             None)
-
-
-def suite():
-    return unittest.TestLoader().loadTestsFromName(__name__)
