@@ -1,7 +1,7 @@
 # django-openid-auth -  OpenID integration for django.contrib.auth
 #
 # Copyright (C) 2007 Simon Willison
-# Copyright (C) 2008-2013 Canonical Ltd.
+# Copyright (C) 2008-2020 Canonical Ltd.
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions
@@ -27,19 +27,20 @@
 # ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
-from django.conf.urls.defaults import *
+from django.conf.urls import include, url
 from django.contrib import admin
+from django.contrib.auth import logout
 
-import views
+from example_consumer import views
 
 
 admin.autodiscover()
 
-urlpatterns = patterns('',
-    (r'^$', views.index),
-    (r'^openid/', include('django_openid_auth.urls')),
-    (r'^logout/$', 'django.contrib.auth.views.logout'),
-    (r'^private/$', views.require_authentication),
+urlpatterns = [
+    url(r'^$', views.index),
+    url(r'^openid/', include('django_openid_auth.urls')),
+    url(r'^logout/$', logout),
+    url(r'^private/$', views.require_authentication),
+]
 
-    (r'^admin/', include(admin.site.urls)),
-)
+urlpatterns.append(url(r'^admin/', admin.site.urls))
